@rem *************************************************************************
@rem This script is used to install WebLogic Server as a service for the 
@rem domain in the current working directory.  
@rem
@rem To create your own domain script, all you need to set is 
@rem SERVER_NAME, then call %WL_HOME%\server\bin\installSvc.cmd
@rem
@rem Other variables that installService takes are:
@rem
@rem WLS_USER     - cleartext user for server startup
@rem WLS_PW       - cleartext password for server startup
@rem PRODUCTION_MODE    - true for production mode servers, false for 
@rem                development mode
@rem JAVA_OPTIONS - Java command-line options for running the server. (These
@rem                will be tagged on to the end of the JAVA_VM and MEM_ARGS)
@rem JAVA_VM      - The java arg specifying the VM to run.  (i.e. -server, 
@rem                -hotspot, etc.)
@rem MEM_ARGS     - The variable to override the standard memory arguments
@rem                passed to java
@rem
@rem For additional information, refer to the WebLogic Server Administration 
@rem Console Online Help(@DOCSWEBROOT/ConsoleHelp/startstop.html)
@rem *************************************************************************

@echo off
SETLOCAL

set DOMAIN_NAME=@DOMAIN_NAME

set USERDOMAIN_HOME=@USERDOMAIN_HOME
for %%i in ("%USERDOMAIN_HOME%") do set USERDOMAIN_HOME=%%~fsi

@rem Set WLS_USER equal to your system username and WLS_PW equal  
@rem to your system password for no username and password prompt 
@rem during server startup.  Both are required to bypass the startup
@rem prompt.
set WLS_USER=@DOMAIN_USER


if NOT "%1" == "" set WLS_USER=%1
shift
if NOT "%1" == "" set WLS_PW=%1
shift 

if "%WLS_USER%" == "" goto usage
if "%WLS_PW%" == ""  goto usage
goto continue

:usage
echo Need to set WLS_USER and WLS_PW environment variables or specify
echo them in command line:
echo Usage: %0 [WLS_USER] [WLS_PW]
echo for example:
echo %0 user password
goto finish

:continue
rem Call setdomainEnv with the DEFAULT settings seen below. If you want to change these you MUST edit
rem  the line
call %USERDOMAIN_HOME%\setDomainEnv.cmd production nodebug

REM this "extra" file is needed because otherwise the command-line to install the service is too long !
set CLASSPATH_FILE=service_classpath.txt
echo %CLASSPATH% > %CLASSPATH_FILE%

set BEASVC_SUFFIX=-javahome:%JAVA_HOME% -execdir:%USERDOMAIN_HOME%

REM Need to set these environment vars OUTSIDE of the IF statements that reference them because
REM otherwise immediate variable expansion will fail to fill in the values.
set DEBUGGER_CMDLINE="-classpath %DEBUG_CLASSPATH% %DBG_JAVA_OPTIONS% weblogic.debugging.engine.DbgMain"
set POINTBASE_CMDLINE="-classpath @%CLASSPATH_FILE% -Dserver.port=@DB_PORT -Ddebug.log=false -Dpointbase.ini=pointbase.ini com.pointbase.net.netServer"

if "%ADMIN_URL%" == "" goto runAdmin
set CMDLINE="%JAVA_VM% %MEM_ARGS% %JAVA_OPTIONS% -classpath @%CLASSPATH_FILE% -Dweblogic.Name=%SERVER_NAME% -Dweblogic.management.username=%WLS_USER% -Dweblogic.management.server=\"%ADMIN_URL%\" -Dweblogic.ProductionModeEnabled=%PRODUCTION_MODE% -Djava.security.policy=\"%WL_HOME%\server\lib\weblogic.policy\" weblogic.Server"
goto installSvc

:runAdmin
set CMDLINE="%JAVA_VM% %MEM_ARGS% %JAVA_OPTIONS% -classpath @%CLASSPATH_FILE% -Dweblogic.Name=%SERVER_NAME% -Dweblogic.management.username=%WLS_USER% -Dweblogic.ProductionModeEnabled=%PRODUCTION_MODE% -Djava.security.policy=\"%WL_HOME%\server\lib\weblogic.policy\" weblogic.Server"

:installSvc
rem *** Set up extrapath for win32 and win64 platform separately
if not "%WL_USE_64BITDLL%" == "true" set EXTRAPATH=%WL_HOME%\server\bin;%JAVA_HOME%\jre\bin;%JAVA_HOME%\bin;%WL_HOME%\server\bin\oci920_8
if "%WL_USE_64BITDLL%" == "true" set EXTRAPATH=%WL_HOME%\server\bin\win64;%WL_HOME%\server\bin;%JAVA_HOME%\jre\bin;%JAVA_HOME%\bin;%WL_HOME%\server\bin\win64\oci920_8

REM Let's remove the all the services that might actually be "installed"
%WL_HOME%\server\bin\beasvc -remove -svcname:"beasvc_%DOMAIN_NAME%_debugger"      > nul
%WL_HOME%\server\bin\beasvc -remove -svcname:"beasvc_%DOMAIN_NAME%_pointbase"     > nul
%WL_HOME%\server\bin\beasvc -remove -svcname:"beasvc_%DOMAIN_NAME%_%SERVER_NAME%" > nul

if "%debugFlag%" == "true" (
    rem *** Install the debugger service (if needed)
    echo Installing the Debugger as a service..
    %WL_HOME%\server\bin\beasvc -install -svcname:"beasvc_%DOMAIN_NAME%_debugger" -cmdline:%DEBUGGER_CMDLINE%  %BEASVC_SUFFIX% 
    set DEPENDENCY_LIST=-depend:beasvc_%DOMAIN_NAME%_debugger
    echo Done.
)

if "%pointbaseFlag%" == "true" (
    rem *** Install pointbase service (if needed)
    echo Installing Pointbase as a service..
    %WL_HOME%\server\bin\beasvc -install -svcname:"beasvc_%DOMAIN_NAME%_pointbase" -cmdline:%POINTBASE_CMDLINE% %BEASVC_SUFFIX%
    if "%DEPENDENCY_LIST%" == "" (
        set DEPENDENCY_LIST=-depend:beasvc_%DOMAIN_NAME%_pointbase
    )else (
        set DEPENDENCY_LIST=%DEPENDENCY_LIST%,beasvc_%DOMAIN_NAME%_pointbase
    )    
    echo Done.
)
        set DEPENDENCY_LIST="%DEPENDENCY_LIST%"

echo Installing Server as a service..
%WL_HOME%\server\bin\beasvc -install %DEPENDENCY_LIST% -svcname:"beasvc_%DOMAIN_NAME%_%SERVER_NAME%" -extrapath:"%EXTRAPATH%" -password:"%WLS_PW%" -cmdline:%CMDLINE% %BEASVC_SUFFIX% 
echo Done
:finish
ENDLOCAL
